#!/bin/bash

## This is the script jenkins should run to execute this test run
## Intersting variables that can be overriden:
##  ANDROID_SERIAL - specify another android device
##  NCD_BANK NCD_RELAY - NCD relay controller id's for the device's USB cable
##  USB_POWER - the script to run to turn on/off USB
##  UTAH_BRANCH - normally we use the installed UTAH, this allows using a branch
##  EXTRA_ARGS - extra CLI args passed the the run_utah_phablet.py script. This
##               allows you to something like "--skip-install"
##  QUICK - sets IDLE_TIMEOUT and SKIP_SETUP to make the job run fast for testing

set -e

BASEDIR=$(dirname $(readlink -f $0))

RESDIR=`pwd`/clientlogs
UTAHFILE=${RESDIR}/utah.yaml

RUNLIST="${BASEDIR}/../master.run"
UTAH_PHABLET_CMD="/usr/share/utah/examples/run_utah_phablet.py"

ANDROID_SERIAL="${ANDROID_SERIAL-015d1884b20c1c0f}"  #doanac's nexus7 at home
# the bank 0-based bank and relay ID for the device's NCD relay control
NCD_BANK="${NCD_BANK-0}"
NCD_RELAY="${NCD_RELAY-0}"
USB_POWER="${USB_POWER-/usr/bin/ncd_usb.py -b $NCD_BANK -r $NCD_RELAY}"

NETWORK_FILE="${NETWORK_FILE-/home/ubuntu/magners-wifi}"

cleanup() {
	set +e
	${USB_POWER} on
}

main() {
	rm -rf clientlogs
	mkdir clientlogs

	if [ -n "$UTAH_BRANCH" ] ; then
		echo "running utah from branch: ${UTAH_BRANCH}"
		[ -d utah ] && rm -rf utah
		BZR_HOME=/dev/null bzr branch ${UTAH_BRANCH} utah
		UTAH_PHABLET_CMD=`pwd`/utah/examples/run_utah_phablet.py
		PYTHONPATH=`pwd`/utah
		cat >${RESDIR}/utah <<EOF
#!/bin/sh
export PYTHONPATH=$PYTHONPATH
export USB_POWER="$USB_POWER"
export ANDROID_SERIAL=$ANDROID_SERIAL
sudo $PYTHONPATH/client.py \$*
EOF
		chmod +x ${RESDIR}/utah
		export PATH=${RESDIR}:$PATH
	fi

	# this is odd bash stuff to deal with the spaces and quotes required:
	[ -z $QUICK ] || ENVS=(--env "IDLE_TIMEOUT=2s SKIP_SETUP=1")

	set -x
	adb -s ${ANDROID_SERIAL} root
	adb -s ${ANDROID_SERIAL} wait-for-device
	PYTHONPATH=$PYTHONPATH ${UTAH_PHABLET_CMD} \
		--from-host \
		--network-file=${NETWORK_FILE} \
		-s ${ANDROID_SERIAL} \
		--results-dir ${RESDIR} \
		-l ${RUNLIST} \
		"${ENVS[@]}" ${EXTRA_ARGS}

	if ! `grep "^errors: [!0]" < $UTAHFILE >/dev/null` ; then
	  echo "errors found"
	  exit 1
	fi
	if ! `grep "^failures: [!0]" < $UTAHFILE >/dev/null` ; then
	  echo "failures found"
	  exit 2
	fi
}

trap cleanup TERM INT EXIT
main
