#!/usr/bin/python

from __future__ import print_function

import atexit
import sys
import subprocess
import time

from gi.repository import Gio

CAPACITY_FILE = '/sys/class/power_supply/battery/capacity'

# NOTE: 1hr (3600) is the largest allowable activity-timeout.
ACTIVITY_TIMEOUT = 3600

_settings = Gio.Settings('com.canonical.powerd')


def _restart_powerd(timeout):
    _settings.set_uint('activity-timeout', timeout)
    subprocess.check_call(['/sbin/restart', 'powerd'])


def _setup():
    print('updating the activity-timeout to help burn battery...')
    _setup.original_timeout = _settings.get_uint('activity-timeout')
    _restart_powerd(ACTIVITY_TIMEOUT)


def _teardown():
    if _setup.original_timeout:
        print('restoring activity-timeout to original value')
        _restart_powerd(_setup.original_timeout)


def main():
    _setup.original_timeout = None
    atexit.register(_teardown)
    _setup()

    # powerd allows 1 hour max to keep screen on, so we have to restart it
    # once every TIMEOUT seconds to keep the battery draining as we need
    last_powerd = time.time()

    while True:
        cap = int(open(CAPACITY_FILE).read())
        if cap < 20:
            print("ERROR: Battery charge too low")
            sys.exit(1)
        elif cap < 90:
            print("capacity at: {}".format(cap))
            break

        if time.time() - last_powerd > ACTIVITY_TIMEOUT:
            print('restarting powerd because of TIMEOUT timeout')
            _restart_powerd(ACTIVITY_TIMEOUT)

        # we need to burn down the cpu a bit
        fmt = "capacity {}%, burning cpu for 240 seconds and trying again..."
        print(fmt.format(cap))
        subprocess.call(['timeout', '240', 'burnCortexA9'])

if __name__ == '__main__':
    main()
